@@ -3,7 +3,7 @@ import strax
 import numpy as np
 
 from straxen.common import pax_file, get_resource, first_sr1_run, aux_repo
-from straxen.get_corrections import get_elife
+from straxen.get_corrections import get_elife, get_config_from_cmt
 from straxen.itp_map import InterpolatingMap
 export, __all__ = strax.exporter()
 
@@ -16,10 +16,10 @@ export, __all__ = strax.exporter()
     strax.Option('trigger_max_competing', default=7,
                  help='Peaks must have FEWER nearby larger or slightly smaller'
                       ' peaks to cause events'),
-    strax.Option('left_event_extension', default=int(1e6),
+    strax.Option('left_event_extension', default=int(2.7e6),
                  help='Extend events this many ns to the left from each '
                       'triggering peak'),
-    strax.Option('right_event_extension', default=int(1e6),
+    strax.Option('right_event_extension', default=int(0.5e6),
                  help='Extend events this many ns to the right from each '
                       'triggering peak'),
 )
@@ -107,7 +107,7 @@ class EventBasics(strax.LoopPlugin):
     The main S2 and alternative S2 are given by the largest two S2-Peaks
     within the event. By default this is also true for S1.
     """
-    __version__ = '0.5.5'
+    __version__ = '0.5.7'
 
     depends_on = ('events',
                   'peak_basics',
@@ -198,9 +198,9 @@ class EventBasics(strax.LoopPlugin):
                       endtime=strax.endtime(event))
         posrec_result = dict(time=event['time'],
                              endtime=strax.endtime(event))
-        posrec_save = (d.replace("s2_", "").replace("alt_", "")
+        posrec_save = [d.replace("s2_", "").replace("alt_", "")
                        for d in self.dtype_for('event_posrec_many').names if
-                       'time' not in d)
+                       'time' not in d]
 
         if not len(peaks):
             return result
@@ -260,7 +260,7 @@ class EventBasics(strax.LoopPlugin):
                     result[f'alt_s{s_i}_{name}'] = secondary_s[s_i][name]
                 if s_i == 2:
                     for name in posrec_save:
-                        posrec_result[f's{s_i}_{name}'] = main_s[s_i][name]
+                        posrec_result[f'alt_s{s_i}_{name}'] = secondary_s[s_i][name]
                 # Compute delay time properties
                 result[f'alt_s{s_i}_delay'] = (secondary_s[s_i]['center_time']
                                                - main_s[s_i]['center_time'])
@@ -366,8 +366,10 @@ class EventPositions(strax.Plugin):
             (0, pax_file('XENON1T_s1_xyz_lce_true_kr83m_SR0_pax-680_fdc-3d_v0.json')),  # noqa
             (first_sr1_run, pax_file('XENON1T_s1_xyz_lce_true_kr83m_SR1_pax-680_fdc-3d_v0.json'))]),  # noqa
     strax.Option(
-        's2_relative_lce_map',
-        help="S2 relative LCE(x, y) map",
+        's2_xy_correction_map',
+        help="S2 (x, y) correction map. Correct S2 position dependence "
+             "manly due to bending of anode/gate-grid, PMT quantum efficiency "
+             "and extraction field distribution, as well as other geometric factors.",
         default_by_run=[
             (0, pax_file('XENON1T_s2_xy_ly_SR0_24Feb2017.json')),
             (170118_1327, pax_file('XENON1T_s2_xy_ly_SR1_v2.2.json'))]),
@@ -403,10 +405,11 @@ class CorrectedAreas(strax.Plugin):
              ] + strax.time_fields
 
     def setup(self):
+
         self.s1_map = InterpolatingMap(
-            get_resource(self.config['s1_relative_lce_map']))
+                get_resource(self.config['s1_relative_lce_map']))
         self.s2_map = InterpolatingMap(
-            get_resource(self.config['s2_relative_lce_map']))
+                get_resource(get_config_from_cmt(self.run_id, self.config['s2_xy_correction_map'])))
         self.elife = get_elife(self.run_id, self.config['elife_file'])
 
     def compute(self, events):
@@ -466,6 +469,7 @@ class EnergyEstimates(strax.Plugin):
         ('e_charge', np.float32, 'Energy in charge signal [keVee]'),
         ('e_ces', np.float32, 'Energy estimate [keVee]')
     ] + strax.time_fields
+    save_when = strax.SaveWhen.TARGET
 
     def compute(self, events):
         el = self.cs1_to_e(events['cs1'])
