@@ -3,7 +3,7 @@ import straxen
 import pandas
 import os
 import tempfile
-from .test_basics import test_run_id
+from .test_basics import test_run_id_1T
 import numpy as np
 import strax
 from matplotlib.pyplot import clf as plt_clf
@@ -58,11 +58,13 @@ def test_several():
 
             print("Downloading test data (if needed)")
             st = straxen.contexts.demo()
+            st.make(test_run_id_1T, 'records')
             # Ignore strax-internal warnings
             st.set_context_config({'free_options': tuple(st.config.keys())})
+            st.make(test_run_id_1T, 'records')
 
             print("Get peaks")
-            p = st.get_array(test_run_id, 'peaks')
+            p = st.get_array(test_run_id_1T, 'peaks')
 
             # Do checks on there number of peaks
             assertion_statement = ("Got /more peaks than expected, perhaps "
@@ -71,50 +73,84 @@ def test_several():
             assert np.abs(len(p) -
                           EXPECTED_OUTCOMES_TEST_SEVERAL['n_peaks']) < 5, assertion_statement
 
-            events = st.get_array(test_run_id, 'event_info')
+            events = st.get_array(test_run_id_1T, 'event_info')
             print('plot wf')
             peak_i = 0
-            st.plot_waveform(test_run_id, time_range=(p[peak_i]['time'], strax.endtime(p[peak_i])))
+            st.plot_waveform(test_run_id_1T, time_range=(p[peak_i]['time'], strax.endtime(p[peak_i])))
             plt_clf()
 
             print('plot hit pattern')
             peak_i = 1
-            st.plot_hit_pattern(test_run_id, time_range=(p[peak_i]['time'], strax.endtime(p[peak_i])), xenon1t=True)
+            st.plot_hit_pattern(test_run_id_1T, time_range=(p[peak_i]['time'], strax.endtime(p[peak_i])), xenon1t=True)
             plt_clf()
 
-            print('plot records matrix')
+            print('plot (raw)records matrix')
             peak_i = 2
-            assert st.is_stored(test_run_id, 'records'), "no records"
-            st.plot_records_matrix(test_run_id, time_range=(p[peak_i]['time'], strax.endtime(p[peak_i])))
+            assert st.is_stored(test_run_id_1T, 'records'), "no records"
+            assert st.is_stored(test_run_id_1T, 'raw_records'), "no raw records"
+            st.plot_records_matrix(test_run_id_1T, time_range=(p[peak_i]['time'],
+                                                            strax.endtime(p[peak_i])))
+            st.raw_records_matrix(test_run_id_1T, time_range=(p[peak_i]['time'],
+                                                           strax.endtime(p[peak_i])))
             plt_clf()
 
             print('plot event displays')
-            straxen.analyses.event_display.plot_single_event(st, test_run_id, events, xenon1t=True,
-                                                             event_number=0, records_matrix=True)
-            st.event_display_interactive(test_run_id, time_range=(events[0]['time'],
+            straxen.analyses.event_display.plot_single_event(st,
+                                                             test_run_id_1T,
+                                                             events,
+                                                             xenon1t=True,
+                                                             event_number=0,
+                                                             records_matrix=True)
+            plt_clf()
+            straxen.analyses.event_display.plot_single_event(st,
+                                                             test_run_id_1T,
+                                                             events,
+                                                             xenon1t=True,
+                                                             event_number=0,
+                                                             records_matrix='raw')
+            plt_clf()
+            st.event_display_interactive(test_run_id_1T, time_range=(events[0]['time'],
                                                                   events[0]['endtime']),
                                          xenon1t=True)
             plt_clf()
 
             print('plot aft')
-            st.plot_peaks_aft_histogram(test_run_id)
+            st.plot_peaks_aft_histogram(test_run_id_1T)
             plt_clf()
 
             print('plot event scatter')
-            st.event_scatter(test_run_id)
+            st.event_scatter(test_run_id_1T)
             plt_clf()
 
             print('plot event scatter')
-            st.plot_energy_spectrum(test_run_id)
+            st.plot_energy_spectrum(test_run_id_1T)
             plt_clf()
 
+            print('plot peak clsassification')
+            st.plot_peak_classification(test_run_id_1T)
+            plt_clf()
+
+            print("plot holoviews")
+            peak_i = 3
+            st.waveform_display(test_run_id_1T,
+                                time_range=(p[peak_i]['time'],
+                                            strax.endtime(p[peak_i])))
+            st.hvdisp_plot_pmt_pattern(test_run_id_1T,
+                                time_range=(p[peak_i]['time'],
+                                            strax.endtime(p[peak_i])))
+            st.hvdisp_plot_peak_waveforms(test_run_id_1T,
+                                time_range=(p[peak_i]['time'],
+                                            strax.endtime(p[peak_i])))
+            print('Plot single pulse:')
+            st.plot_pulses_tpc(test_run_id_1T, max_plots=2,  plot_hits=True, ignore_time_warning=True)
+
             print("Check live-time")
-            live_time = straxen.get_livetime_sec(st, test_run_id, things=p)
-            assertion_statement = ("Live-time calculation is wrong")
+            live_time = straxen.get_livetime_sec(st, test_run_id_1T, things=p)
+            assertion_statement = "Live-time calculation is wrong"
             assert live_time == EXPECTED_OUTCOMES_TEST_SEVERAL['run_live_time'], assertion_statement
 
             print('Check the peak_basics')
-            df = st.get_df(test_run_id, 'peak_basics')
+            df = st.get_df(test_run_id_1T, 'peak_basics')
             assertion_statement = ("Got less/more S1s than expected, perhaps "
                                    "the test is outdated or classification "
                                    "has really changed.")
@@ -125,7 +161,7 @@ def test_several():
             print("Check that we can write nice wiki dfs")
             straxen.dataframe_to_wiki(df)
 
-            print("Abbuse the peaks to show that _average_scada works")
+            print("Abuse the peaks to show that _average_scada works")
             p = p[:10]
             p_t, p_a = straxen.scada._average_scada(
                 p['time']/1e9,
@@ -134,7 +170,7 @@ def test_several():
             assert len(p_a) == len(p), 'Scada deleted some of my 10 peaks!'
 
             print('Check the number of events')
-            events = st.get_array(test_run_id, 'event_info')
+            events = st.get_array(test_run_id_1T, 'event_info_double')
             assertion_statement = ("Got less/ore events than expected, "
                                    "perhaps the test is outdated or something "
                                    "changed in the processing.")
@@ -150,3 +186,7 @@ def test_plots():
     c = np.ones(straxen.n_tpc_pmts)
     straxen.plot_pmts(c)
     straxen.plot_pmts(c, log_scale=True)
+
+
+def test_print_version():
+    straxen.print_versions(['strax', 'something_that_does_not_exist'])
